@@ -8,6 +8,7 @@ use std::path::{Path, PathBuf};
 use std::process::{Command, Stdio};
 
 use crate::base::fileset::copy_filesets;
+use crate::base::utils;
 use crate::base::Arch;
 use crate::config::{get_binary_dir, Config, LinuxConfig};
 use crate::error::{Error, ErrorKind};
@@ -29,6 +30,8 @@ pub fn build_app_image(conf: &Config, linux_conf: &LinuxConfig, arch: Arch) -> R
     let workdir = Path::new(&conf.metadata.workdir);
     let app_image_dir_name = "app_image";
     let app_image_dir = workdir.join(app_image_dir_name);
+    utils::rmdir(&app_image_dir)?;
+
     let libs_dir = app_image_dir.join("libs");
     fs::create_dir_all(&app_image_dir)?;
 
@@ -73,7 +76,7 @@ fn get_appimage_tool(arch: Arch) -> Result<PathBuf, Error> {
 
 fn compile_app_image<P: AsRef<Path>>(workdir: &Path, dir: &P, arch: Arch) -> Result<(), Error> {
     let appimage_tool = get_appimage_tool(arch)?;
-    log::info!("Using {:?}", &appimage_tool);
+    log::info!("Using appimagetool: {:?}", &appimage_tool);
     let mut cmd = Command::new(appimage_tool.as_os_str());
     if cfg!(not(debug_assertions)) {
         cmd.stdout(Stdio::null()).stderr(Stdio::null());
@@ -84,7 +87,14 @@ fn compile_app_image<P: AsRef<Path>>(workdir: &Path, dir: &P, arch: Arch) -> Res
         .arg(dir.as_ref())
         .stdout(Stdio::null())
         .stderr(Stdio::null())
-        .status()?;
+        .status()
+        .map_err(|err| {
+            Error::from_string(
+                ErrorKind::AppImageCompilerError,
+                format!("Failed to run `appimagetool` command, error: {:?}, please install with `pifu --download` command", err),
+            )
+        })?;
+
     if status.success() {
         Ok(())
     } else {
