@@ -2,11 +2,13 @@
 // Use of this source is governed by General Public License that can be found
 // in the LICENSE file.
 
-use pifu::{build, Error};
+use pifu::{read_cmdline, Error};
 
 fn main() -> Result<(), Error> {
-    std::env::set_var("RUST_LOG", "info");
+    if cfg!(debug_assertions) {
+        std::env::set_var("RUST_LOG", "info");
+    }
     env_logger::init();
 
-    build()
+    read_cmdline()
 }
