@@ -11,16 +11,18 @@ use super::config::RpmConfig;
 use crate::base::archive;
 use crate::base::compress;
 use crate::base::fileset::copy_filesets;
+use crate::base::utils;
 use crate::base::Arch;
 use crate::config::{Config, LinuxConfig};
 use crate::error::{Error, ErrorKind};
 
 pub fn build_rpm(conf: &Config, linux_conf: &LinuxConfig, _arch: Arch) -> Result<(), Error> {
-    log::info!("build_rpm() conf: {:?}", conf);
     let rpm_conf = &linux_conf.rpm;
 
     let workdir = Path::new(&conf.metadata.workdir);
     let rpm_dir = workdir.join("rpm");
+    utils::rmdir(&rpm_dir)?;
+
     fs::create_dir_all(&rpm_dir)?;
     let spec_file = rpm_dir.join(format!("{}.spec", &conf.metadata.name));
     let mut spec_fd = File::create(&spec_file).map_err(|err| {
@@ -65,7 +67,10 @@ pub fn build_rpm(conf: &Config, linux_conf: &LinuxConfig, _arch: Arch) -> Result
     let new_source_xz_file = rpm_source_dir.join(format!("{}.tar.xz", &conf.metadata.name));
     fs::rename(&source_xz_file, new_source_xz_file)?;
 
-    generate_rpm_file(&spec_file, &rpm_dir)
+    generate_rpm_file(&spec_file, &rpm_dir)?;
+
+    let rpm_dir = rpm_dir.to_str().unwrap();
+    move_rpm_files(rpm_dir)
 }
 
 fn generate_spec_file(
@@ -132,9 +137,9 @@ fn generate_rpm_file(spec_file: &Path, rpm_dir: &Path) -> Result<(), Error> {
     let def = format!("_topdir {}", fs::canonicalize(rpm_dir)?.display());
 
     let mut cmd = Command::new("rpmbuild");
-    if cfg!(not(debug_assertions)) {
-        cmd.stdout(Stdio::null()).stderr(Stdio::null());
-    }
+    //if cfg!(not(debug_assertions)) {
+    cmd.stdout(Stdio::null()).stderr(Stdio::null());
+    //}
     // Change rootdir of rpm build.
     let status = cmd
         .arg("-D")
@@ -158,3 +163,8 @@ fn generate_rpm_file(spec_file: &Path, rpm_dir: &Path) -> Result<(), Error> {
         ))
     }
 }
+
+fn move_rpm_files(rpm_dir: &str) -> Result<(), Error> {
+    let rpm_files = format!("{}/RPMS/*/*.rpm", rpm_dir);
+    utils::mv(&rpm_files, rpm_dir)
+}
